@@ -25,7 +25,7 @@
 #include <egg-screen-help.h>
 #include "geyes.h"
 
-#define UPDATE_TIMEOUT 75
+#define UPDATE_TIMEOUT 100
 
 static void
 applet_set_back_pixmap (GtkWidget *widget, const gchar *pixmap)
@@ -85,7 +85,7 @@ applet_back_change (PanelApplet *a,
                 
 	switch (type) {
 	case PANEL_PIXMAP_BACKGROUND:
-                applet_set_back_pixmap (eyes_applet->fixed, pixmap);
+                applet_set_back_pixmap (eyes_applet->vbox, pixmap);
 		break;
         case PANEL_COLOR_BACKGROUND:
                 for (i = 0; i < eyes_applet->num_eyes; i++) {
@@ -117,11 +117,11 @@ calculate_pupil_xy (EyesApplet *eyes_applet,
         double nx;
         double ny;
         double h;
-        
+        double temp;
+     
         nx = x - ((double) eyes_applet->eye_width / 2);
         ny = y - ((double) eyes_applet->eye_height / 2);
-        
-        angle = atan2 (nx, ny);
+       
         h = hypot (nx, ny);
         if (abs (h) 
             < (abs (hypot (eyes_applet->eye_height / 2, eyes_applet->eye_width / 2)) - eyes_applet->wall_thickness - eyes_applet->pupil_height)) {
@@ -130,15 +130,21 @@ calculate_pupil_xy (EyesApplet *eyes_applet,
                 return;
         }
         
+        angle = atan2 (nx, ny);
         sina = sin (angle);
         cosa = cos (angle);
         
-        *pupil_x = hypot ((eyes_applet->eye_height / 2) * cosa, (eyes_applet->eye_width / 2)* sina) * sina;
-        *pupil_y = hypot ((eyes_applet->eye_height / 2) * cosa, (eyes_applet->eye_width / 2)* sina) * cosa;
-        *pupil_x -= hypot ((eyes_applet->pupil_width / 2) * sina, (eyes_applet->pupil_height / 2)* cosa) * sina;
-        *pupil_y -= hypot ((eyes_applet->pupil_width / 2) * sina, (eyes_applet->pupil_height / 2) * cosa) * cosa;
-        *pupil_x -= hypot ((eyes_applet->wall_thickness / 2) * sina, (eyes_applet->wall_thickness / 2) * cosa) * sina;
-        *pupil_y -= hypot ((eyes_applet->wall_thickness / 2) * sina, (eyes_applet->wall_thickness / 2)* cosa) * cosa;
+        temp = hypot ((eyes_applet->eye_height / 2) * cosa, (eyes_applet->eye_width / 2)* sina);
+        *pupil_x = temp * sina;
+        *pupil_y = temp * cosa;
+       
+        temp = hypot ((eyes_applet->pupil_width / 2) * sina, (eyes_applet->pupil_height / 2)* cosa);
+        *pupil_x -= temp * sina;
+        *pupil_y -= temp * cosa;
+        
+        temp = hypot ((eyes_applet->wall_thickness / 2) * sina, (eyes_applet->wall_thickness / 2) * cosa);
+        *pupil_x -= temp * sina;
+        *pupil_y -= temp * cosa;
         
         *pupil_x += (eyes_applet->eye_width / 2);
         *pupil_y += (eyes_applet->eye_height / 2);
@@ -150,30 +156,32 @@ draw_eye (EyesApplet *eyes_applet,
           gint pupil_x, 
           gint pupil_y)
 {
-	gdk_pixbuf_render_to_drawable_alpha (eyes_applet->eye_image, 
-					     eyes_applet->eyes[eye_num]->window,
-					     0, 0, 
-                         		     0, 0,
-                         		     eyes_applet->eye_width, 
-                         		     eyes_applet->eye_height,
-                         		     GDK_PIXBUF_ALPHA_BILEVEL,
-                         		     128,
-                         		     GDK_RGB_DITHER_NONE,
-                         		     0,
-                         		     0);
-        
-	gdk_pixbuf_render_to_drawable_alpha (eyes_applet->pupil_image, 
-					     eyes_applet->eyes[eye_num]->window,
-					     0, 0, 
-                         		     pupil_x - eyes_applet->pupil_width / 2, 
-                         		     pupil_y - eyes_applet->pupil_height / 2,
-                         		     -1, -1,
-                         		     GDK_PIXBUF_ALPHA_BILEVEL,
-                         		     128,
-                         		     GDK_RGB_DITHER_NONE,
-                         		     0,
-                         		     0);
- 
+	GdkPixbuf *pixbuf;
+	GdkRectangle rect, r1, r2;
+
+	pixbuf = gdk_pixbuf_copy (eyes_applet->eye_image);
+	r1.x = pupil_x - eyes_applet->pupil_width / 2;
+	r1.y = pupil_y - eyes_applet->pupil_height / 2;
+	r1.width = eyes_applet->pupil_width;
+	r1.height = eyes_applet->pupil_height;
+	r2.x = 0;
+	r2.y = 0;
+	r2.width = eyes_applet->eye_width;
+	r2.height = eyes_applet->eye_height;
+	gdk_rectangle_intersect (&r1, &r2, &rect);
+	gdk_pixbuf_composite (eyes_applet->pupil_image, pixbuf, 
+					   rect.x,
+					   rect.y,
+					   rect.width,
+				      	   rect.height,
+				      	   pupil_x - eyes_applet->pupil_width / 2,
+					   pupil_y - eyes_applet->pupil_height / 2, 1.0, 1.0,
+				      	   GDK_INTERP_BILINEAR,
+				           255);
+	gtk_image_set_from_pixbuf (GTK_IMAGE (eyes_applet->eyes[eye_num]),
+						  pixbuf);
+	g_object_unref (pixbuf);
+
 }
 
 static gint 
@@ -185,13 +193,16 @@ timer_cb (EyesApplet *eyes_applet)
         
         for (i = 0; i < eyes_applet->num_eyes; i++) {
 		if (GTK_WIDGET_REALIZED (eyes_applet->eyes[i])) {
-			gdk_window_get_pointer (eyes_applet->eyes[i]->window, 
-						&x, &y, NULL);
-			calculate_pupil_xy (eyes_applet, x, y, &pupil_x, &pupil_y);
-			draw_eye (eyes_applet, i, pupil_x, pupil_y);
+			gtk_widget_get_pointer (eyes_applet->eyes[i], 
+						&x, &y);
+			if ((x != eyes_applet->pointer_last_x) || (y != eyes_applet->pointer_last_y)) { 
+				calculate_pupil_xy (eyes_applet, x, y, &pupil_x, &pupil_y);
+				draw_eye (eyes_applet, i, pupil_x, pupil_y);
+			}
 		}
         }
-        
+        eyes_applet->pointer_last_x = x;
+        eyes_applet->pointer_last_y = y;
         return TRUE;
 }
 
@@ -276,11 +287,10 @@ setup_eyes (EyesApplet *eyes_applet)
 	int i;
 
         eyes_applet->hbox = gtk_hbox_new (FALSE, 0);
-        gtk_fixed_put (GTK_FIXED (eyes_applet->fixed), eyes_applet->hbox, 0, 0);
+        gtk_box_pack_start (GTK_BOX (eyes_applet->vbox), eyes_applet->hbox, TRUE, TRUE, 0);
 
         for (i = 0; i < eyes_applet->num_eyes; i++) {
-                eyes_applet->eyes[i] = gtk_drawing_area_new ();
-                
+                eyes_applet->eyes[i] = gtk_image_new ();
                 if (eyes_applet->eyes[i] == NULL)
                         g_error ("Error creating geyes\n");
                
@@ -296,6 +306,16 @@ setup_eyes (EyesApplet *eyes_applet)
                                     TRUE,
                                     0);
                 
+		if ((eyes_applet->num_eyes != 1) && (i == 0)) {
+                	gtk_misc_set_alignment (GTK_MISC (eyes_applet->eyes[i]), 1.0, 0.5);
+		}
+		else if ((eyes_applet->num_eyes != 1) && (i == eyes_applet->num_eyes - 1)) {
+			gtk_misc_set_alignment (GTK_MISC (eyes_applet->eyes[i]), 0.0, 0.5);
+		}
+		else {
+			gtk_misc_set_alignment (GTK_MISC (eyes_applet->eyes[i]), 0.5, 0.5);
+		}
+		
                 gtk_widget_realize (eyes_applet->eyes[i]);
 		draw_eye (eyes_applet, i,
 			  eyes_applet->eye_width / 2,
@@ -318,9 +338,9 @@ create_eyes (PanelApplet *applet)
 	EyesApplet *eyes_applet = g_new0 (EyesApplet, 1);
 
         eyes_applet->applet = applet;
-        eyes_applet->fixed  = gtk_fixed_new ();
+        eyes_applet->vbox = gtk_vbox_new (FALSE, 0);
 
-	gtk_container_add (GTK_CONTAINER (applet), eyes_applet->fixed);
+	gtk_container_add (GTK_CONTAINER (applet), eyes_applet->vbox);
 
         properties_load (eyes_applet);
 
@@ -357,6 +377,9 @@ destroy_cb (GtkObject *object, EyesApplet *eyes_applet)
 		g_free (eyes_applet->pupil_filename);
 	eyes_applet->pupil_filename = NULL;
 	
+	if (eyes_applet->prop_box.pbox)
+	  gtk_widget_destroy (eyes_applet->prop_box.pbox);
+
 	g_free (eyes_applet);
 }
 
@@ -367,9 +390,10 @@ help_cb (BonoboUIComponent *uic,
 {
 	GError *error = NULL;
 
-	egg_screen_help_display (
+	egg_help_display_on_screen (
+		"geyes", NULL,
 		gtk_widget_get_screen (GTK_WIDGET (eyes_applet->applet)),
-		"geyes", NULL, &error);
+		&error);
 
 	if (error) { /* FIXME: the user needs to see this */
 		g_warning ("help error: %s\n", error->message);
@@ -408,6 +432,7 @@ geyes_applet_fill (PanelApplet *applet)
 	EyesApplet *eyes_applet;
 	
 	gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-eyes.png");
+	panel_applet_set_flags (applet, PANEL_APPLET_EXPAND_MINOR);
 	
         eyes_applet = create_eyes (applet);
 
@@ -423,6 +448,17 @@ geyes_applet_fill (PanelApplet *applet)
 				           geyes_applet_menu_verbs,
 				           eyes_applet);
 
+	if (panel_applet_get_locked_down (eyes_applet->applet)) {
+		BonoboUIComponent *popup_component;
+
+		popup_component = panel_applet_get_popup_component (eyes_applet->applet);
+
+		bonobo_ui_component_set_prop (popup_component,
+					      "/commands/Props",
+					      "hidden", "1",
+					      NULL);
+	}
+
 	eyes_applet->tooltips = gtk_tooltips_new ();
 	g_object_ref (eyes_applet->tooltips);
 	gtk_object_sink (GTK_OBJECT (eyes_applet->tooltips));
@@ -437,7 +473,7 @@ geyes_applet_fill (PanelApplet *applet)
 			  "change_background",
 			  G_CALLBACK (applet_back_change),
 			  eyes_applet);
-	g_signal_connect (eyes_applet->fixed,
+	g_signal_connect (eyes_applet->vbox,
 			  "destroy",
 			  G_CALLBACK (destroy_cb),
 			  eyes_applet);
