@@ -256,6 +256,8 @@ gkb_prop_map_edit (GkbPropertyBoxInfo * pbi)
   GtkWidget *vbox1;
   GtkWidget *table1;
   GkbKeymap *keymap;
+  GConfClient *client;
+  gboolean inhibit_command_line;
 
   if (pbi->selected_keymap == NULL)
     {
@@ -263,6 +265,9 @@ gkb_prop_map_edit (GkbPropertyBoxInfo * pbi)
       return;
     }
 
+  client = gconf_client_get_default ();
+  inhibit_command_line = gconf_client_get_bool (client, "/desktop/gnome/lockdown/inhibit_command_line", NULL);
+
   mdi = g_new0 (GkbMapDialogInfo, 1);
   mdi->pbi = pbi;
   mdi->keymap = pbi->selected_keymap;
@@ -281,6 +286,7 @@ gkb_prop_map_edit (GkbPropertyBoxInfo * pbi)
   gtk_dialog_set_has_separator (GTK_DIALOG (mdi->dialog), FALSE);
   gtk_dialog_set_default_response (GTK_DIALOG (mdi->dialog), GTK_RESPONSE_CLOSE);
   gtk_container_set_border_width (GTK_CONTAINER (mdi->dialog), 5);
+  gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (mdi->dialog)->vbox), 2);
   gtk_window_set_resizable (GTK_WINDOW (mdi->dialog), FALSE);
 
   vbox1 = gtk_vbox_new (FALSE, 0);
@@ -302,6 +308,8 @@ gkb_prop_map_edit (GkbPropertyBoxInfo * pbi)
 
   gkb_prop_map_label_at (table1, 0, 2, _("Co_mmand:"));
   mdi->command_entry = gkb_prop_map_entry_at (table1, 1, 2, mdi, keymap->command);
+  if (inhibit_command_line)
+	  gtk_widget_set_sensitive (mdi->command_entry, FALSE);
 
   gkb_prop_map_label_at (table1, 0, 3, _("_Flag:"));
   mdi->flag_entry = gkb_prop_map_icon_entry_at (table1, 1, 3, mdi, keymap->flag);
