@@ -1,7 +1,7 @@
 #ifndef __GWEATHER_APPLET_H_
 #define __GWEATHER_APPLET_H_
 
-/* $Id: gweather-applet.h,v 1.7 2003/02/21 00:48:23 kevinv Exp $ */
+/* $Id: gweather-applet.h,v 1.8 2003/07/13 23:17:52 kevinv Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -20,9 +20,9 @@ G_BEGIN_DECLS
 
 extern void gweather_applet_create(GWeatherApplet *gw_applet);
 extern gint timeout_cb (gpointer data);
-void update_display (GWeatherApplet *applet);
-void place_widgets (GWeatherApplet *gw_applet);
 extern void gweather_update (GWeatherApplet *applet);
+extern void gweather_info_load (const gchar *path, GWeatherApplet *applet);
+extern void gweather_info_save (const gchar *path, GWeatherApplet *applet);
 
 G_END_DECLS
 
